@@ -1,12 +1,7 @@
 module TransducersReferenceablesExt
 
-if isdefined(Base, :get_extension)
-    using Transducers
-    using Referenceables
-else
-    using ..Transducers
-    using ..Referenceables
-end
+using Transducers
+using Referenceables
 
 @inline Transducers.executor_type(x::Referenceables.Referenceable) = Transducers.executor_type(parent(x))
 
